==> qt5-tools-debuginfo-5.9.2-1.tar.xz: usr/src/debug/qt5-tools-5.9.2-1/examples/designer/worldtimeclockbuilder/.rcc/qrc_worldtimeclockbuilder.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-tools/qt5-tools-5.9.2-1.i686/src/qttools-opensource-src-5.9.2/examples/designer/worldtimeclockbuilder/form.ui
  0x0,0x0,0x3,0x5e,
  0x0,
  0x0,0xe,0xa4,0x78,0x9c,0xed,0x56,0x4b,0x4f,0xdc,0x30,0x10,0xbe,0xf3,0x2b,0xa2,
  0x3d,0xb5,0x87,0x92,0x7d,0x41,0xb5,0x28,0xe4,0x50,0xd4,0x8a,0x3,0x52,0x85,0x40,
  0x20,0xf5,0x52,0x99,0xc4,0xdd,0xb5,0x9a,0xd8,0x91,0xe3,0xb0,0x59,0x7e,0x7d,0xc7,
  0xaf,0xc4,0x76,0xb2,0x2c,0x85,0xaa,0x27,0x6e,0x9e,0x19,0xfb,0x9b,0x99,0x6f,0x66,
  0x92,0x49,0x1a,0x12,0x3d,0x62,0x5e,0x13,0x46,0xcf,0x27,0xcb,0xe3,0xe9,0x24,0x4a,
  0x8f,0xa2,0x4,0x35,0x62,0xc3,0x78,0x9a,0xc4,0xe6,0x0,0xaa,0x8c,0x95,0x25,0xa6,
  0x2,0x74,0xf6,0x4,0x4a,0xdc,0x56,0x8c,0x8b,0x12,0x65,0x9c,0x81,0xc1,0x95,0xe4,
  0x8b,0x2,0xd5,0x75,0x7a,0xcf,0x78,0x91,0xdf,0x92,0x12,0x7f,0x63,0xbc,0x84,0xc7,
  0x4a,0x9,0xd6,0x2d,0xc9,0xd7,0x58,0x44,0x4a,0x3e,0x9f,0x5c,0xdf,0x2b,0x71,0x12,
  0x51,0x54,0xe2,0xf3,0x89,0xf7,0x48,0x85,0x14,0x25,0x15,0x67,0x15,0xe6,0x62,0x67,
  0xae,0xac,0x31,0x2b,0xb1,0xe0,0x3b,0x6d,0x8d,0x12,0x8e,0x33,0xa1,0x4e,0x51,0xd2,
  0xa6,0xd3,0x24,0x6e,0x8d,0xb0,0x93,0xc2,0xce,0x8,0xe0,0x54,0x6c,0xd2,0xe5,0x14,
  0x54,0xfa,0xa8,0xd5,0x1b,0x4c,0xd6,0x1b,0x91,0x2e,0xa4,0xde,0x9c,0x15,0x66,0x6c,
  0x41,0x93,0xd8,0x7a,0x1f,0xb,0x65,0x4b,0x68,0xce,0xb6,0xb7,0x44,0x14,0xd8,0x46,
  0x53,0xb,0x4e,0xe8,0x5a,0x27,0x1f,0xc9,0x44,0xa2,0x8b,0x82,0x65,0xbf,0x93,0xd8,
  0x18,0x86,0x98,0x5,0xda,0xb1,0xa6,0xe7,0xe3,0xf2,0xb,0x6b,0xaf,0x94,0xca,0x42,
  0x6,0x4e,0x4b,0xc4,0xd7,0x84,0x1a,0x63,0x94,0xd0,0xa6,0x7c,0xc0,0x3c,0x5d,0x25,
  0xb1,0x39,0xe9,0x4,0x5c,0x17,0x3,0x88,0xba,0x42,0x19,0x4,0x13,0x62,0x9c,0x3e,
  0x8b,0x41,0x4,0x2e,0x7b,0x36,0x9d,0x12,0x76,0x35,0x53,0x99,0xda,0x4a,0x6e,0x3,
  0x6d,0x6c,0x40,0x3b,0x18,0x17,0x30,0xe0,0xe0,0x2e,0xe4,0xe0,0x10,0xb,0x7d,0xe,
  0x33,0x2f,0x87,0x41,0x16,0x7,0xb9,0xd8,0xc7,0xc6,0x18,0x52,0x9f,0x80,0x2c,0x3c,
  0xe0,0x74,0x77,0x87,0x6e,0x18,0x27,0x30,0x3a,0x48,0xc0,0xb8,0xf5,0xae,0xe0,0x1a,
  0x6,0x1f,0xe9,0xb5,0x38,0x3b,0xbb,0x83,0xcb,0x24,0x43,0x5,0x4c,0x93,0x54,0x75,
  0x38,0xa1,0xd7,0x91,0xc,0xc8,0x13,0xbe,0x24,0x54,0x78,0xb8,0x52,0xd9,0x8b,0x76,
  0x0,0xe6,0x7e,0xff,0x47,0xee,0x10,0x2c,0xfd,0x19,0x30,0xde,0x3d,0x9c,0x61,0x30,
  0x70,0xc1,0xcd,0xdb,0x29,0x6f,0xc8,0xcf,0xa1,0x36,0x7f,0x49,0x91,0xf7,0x97,0xf9,
  0x65,0x44,0x85,0xa5,0xde,0x5f,0xec,0x71,0x3c,0x37,0xa1,0xc1,0x18,0x5c,0x5f,0xa1,
  0x7,0x5c,0xd8,0xf6,0x2f,0xb4,0xe0,0xf2,0x1c,0x44,0x23,0x70,0xeb,0x95,0xac,0xff,
  0x78,0x5c,0x34,0x9c,0x43,0xb3,0x44,0x2,0xa6,0xe7,0xcc,0xfd,0x72,0xec,0xf,0x2d,
  0x52,0x75,0x85,0x68,0x9c,0xf8,0xbd,0x68,0xf,0xc4,0x2e,0x7,0xf5,0x6b,0x4e,0xba,
  0xef,0xb0,0xe8,0xe4,0x67,0x32,0xe0,0x18,0xe5,0xdf,0x69,0xb1,0xb,0xb2,0x78,0x60,
  0xac,0x48,0x5,0x6f,0x70,0x12,0xab,0xe3,0x9b,0x2,0x4f,0x62,0xdd,0x38,0xef,0xd,
  0x36,0xd6,0x60,0x3f,0xe7,0xaf,0x6c,0xb1,0x1b,0xac,0xdb,0x2b,0x7a,0x62,0xf4,0x7f,
  0xf5,0xd8,0x4d,0x45,0x28,0x14,0x65,0xd2,0x91,0x65,0xc4,0x67,0x12,0x28,0x51,0x4b,
  0xca,0xa6,0xc,0x72,0xb0,0x25,0x9a,0xf,0x38,0x1d,0x8f,0x7b,0x8,0x4b,0xe8,0x7e,
  0xd8,0x4f,0x2f,0xc6,0xfd,0x67,0xad,0xfb,0xfe,0xef,0x8,0xf8,0xf1,0xa8,0xeb,0xd,
  0x8e,0xda,0xe1,0x3e,0xa9,0x48,0x5b,0xa2,0xea,0x57,0x43,0x33,0x49,0x11,0xec,0xa3,
  0x81,0x42,0xae,0xa4,0x4d,0x2d,0x58,0xa9,0x9f,0xd4,0xa,0xca,0xd5,0x68,0x37,0xc1,
  0xda,0x6a,0xf6,0x36,0xbb,0xb7,0x4a,0xbe,0x5b,0x81,0x69,0x5e,0xab,0x85,0x57,0x9f,
  0x8e,0x34,0x7,0x28,0x87,0x2c,0xd4,0xc2,0x23,0x67,0x2a,0x93,0xf,0x8f,0x37,0x92,
  0x11,0x65,0xd0,0xe0,0xc,0x2a,0x48,0x28,0x88,0x53,0xb9,0x48,0x5b,0x41,0x6f,0x67,
  0x2a,0xdc,0x2e,0x6e,0x9d,0x69,0x10,0x9f,0xaf,0x50,0x8b,0x34,0xc7,0x35,0x6b,0x78,
  0x86,0xeb,0x58,0xaf,0xe9,0x94,0x62,0x95,0xaf,0xc9,0xaf,0x93,0xcd,0x62,0xa,0x1,
  0x83,0x43,0x33,0x75,0xc0,0xbd,0x96,0xb5,0x8d,0xac,0x29,0x2a,0xd2,0x47,0x54,0x34,
  0xf8,0x62,0x83,0xe8,0x1a,0xe7,0x1f,0xa0,0x29,0x3e,0xca,0x12,0x2a,0x8b,0x5d,0xb4,
  0x31,0x79,0xb4,0x99,0x3a,0x14,0x75,0x6,0xd,0x56,0x30,0x91,0xd6,0x58,0xc8,0xb,
  0x3f,0xe0,0xeb,0x62,0x91,0xa4,0x5a,0xf3,0x5,0x8a,0xda,0x2e,0xe0,0x44,0xfe,0xe7,
  0x76,0x95,0x6c,0x45,0x95,0x8c,0xff,0xdf,0x84,0x8d,0x7e,0xb1,0x58,0x75,0x3b,0xbd,
  0x5c,0xea,0x67,0xa7,0xa7,0xfd,0x5a,0x1f,0xcb,0xf7,0x43,0xa8,0x1c,0xd7,0x82,0x50,
  0x35,0x30,0x3,0xbc,0xd9,0xc9,0x67,0xf,0x6f,0xbe,0x98,0x8e,0xe1,0xe9,0x63,0x6d,
  0x6a,0xe1,0x71,0xb9,0x8f,0xda,0x90,0x96,0x11,0x86,0x9b,0x2a,0x47,0x2,0xc8,0x55,
  0xff,0xdb,0x7d,0xf4,0xda,0x7f,0xef,0x73,0xc4,0xf6,0x8,0xaf,0xa4,0x75,0xb6,0x9c,
  0x79,0x34,0x9c,0xac,0xde,0xc4,0xea,0x7c,0xe5,0xc3,0xcd,0x16,0x8b,0xbf,0x63,0xd5,
  0x15,0xc1,0x9e,0xc4,0xd,0x49,0x8f,0xfe,0x0,0xd7,0xf8,0x46,0xff,
  
};

static const unsigned char qt_resource_name[] = {
  // forms
  0x0,0x5,
  0x0,0x6d,0x69,0x43,
  0x0,0x66,
  0x0,0x6f,0x0,0x72,0x0,0x6d,0x0,0x73,
    // form.ui
  0x0,0x7,
  0xd,0x69,0x5,0x79,
  0x0,0x66,
  0x0,0x6f,0x0,0x72,0x0,0x6d,0x0,0x2e,0x0,0x75,0x0,0x69,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/forms
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/forms/form.ui
  0x0,0x0,0x0,0x10,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5e,0xc7,0xb5,0xc8,0xc8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_worldtimeclockbuilder)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_worldtimeclockbuilder)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_worldtimeclockbuilder)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_worldtimeclockbuilder)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_worldtimeclockbuilder)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_worldtimeclockbuilder)(); }
   } dummy;
}

==> qt5-tools-debuginfo-5.9.3-1.tar.xz: usr/src/debug/qt5-tools-5.9.3-1/examples/designer/worldtimeclockbuilder/.rcc/qrc_worldtimeclockbuilder.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-tools/qt5-tools-5.9.3-1.i686/src/qttools-opensource-src-5.9.3/examples/designer/worldtimeclockbuilder/form.ui
  0x0,0x0,0x3,0x5e,
  0x0,
  0x0,0xe,0xa4,0x78,0x9c,0xed,0x56,0x4b,0x4f,0xdc,0x30,0x10,0xbe,0xf3,0x2b,0xa2,
  0x3d,0xb5,0x87,0x92,0x7d,0x41,0xb5,0x28,0xe4,0x50,0xd4,0x8a,0x3,0x52,0x85,0x40,
  0x20,0xf5,0x52,0x99,0xc4,0xdd,0xb5,0x9a,0xd8,0x91,0xe3,0xb0,0x59,0x7e,0x7d,0xc7,
  0xaf,0xc4,0x76,0xb2,0x2c,0x85,0xaa,0x27,0x6e,0x9e,0x19,0xfb,0x9b,0x99,0x6f,0x66,
  0x92,0x49,0x1a,0x12,0x3d,0x62,0x5e,0x13,0x46,0xcf,0x27,0xcb,0xe3,0xe9,0x24,0x4a,
  0x8f,0xa2,0x4,0x35,0x62,0xc3,0x78,0x9a,0xc4,0xe6,0x0,0xaa,0x8c,0x95,0x25,0xa6,
  0x2,0x74,0xf6,0x4,0x4a,0xdc,0x56,0x8c,0x8b,0x12,0x65,0x9c,0x81,0xc1,0x95,0xe4,
  0x8b,0x2,0xd5,0x75,0x7a,0xcf,0x78,0x91,0xdf,0x92,0x12,0x7f,0x63,0xbc,0x84,0xc7,
  0x4a,0x9,0xd6,0x2d,0xc9,0xd7,0x58,0x44,0x4a,0x3e,0x9f,0x5c,0xdf,0x2b,0x71,0x12,
  0x51,0x54,0xe2,0xf3,0x89,0xf7,0x48,0x85,0x14,0x25,0x15,0x67,0x15,0xe6,0x62,0x67,
  0xae,0xac,0x31,0x2b,0xb1,0xe0,0x3b,0x6d,0x8d,0x12,0x8e,0x33,0xa1,0x4e,0x51,0xd2,
  0xa6,0xd3,0x24,0x6e,0x8d,0xb0,0x93,0xc2,0xce,0x8,0xe0,0x54,0x6c,0xd2,0xe5,0x14,
  0x54,0xfa,0xa8,0xd5,0x1b,0x4c,0xd6,0x1b,0x91,0x2e,0xa4,0xde,0x9c,0x15,0x66,0x6c,
  0x41,0x93,0xd8,0x7a,0x1f,0xb,0x65,0x4b,0x68,0xce,0xb6,0xb7,0x44,0x14,0xd8,0x46,
  0x53,0xb,0x4e,0xe8,0x5a,0x27,0x1f,0xc9,0x44,0xa2,0x8b,0x82,0x65,0xbf,0x93,0xd8,
  0x18,0x86,0x98,0x5,0xda,0xb1,0xa6,0xe7,0xe3,0xf2,0xb,0x6b,0xaf,0x94,0xca,0x42,
  0x6,0x4e,0x4b,0xc4,0xd7,0x84,0x1a,0x63,0x94,0xd0,0xa6,0x7c,0xc0,0x3c,0x5d,0x25,
  0xb1,0x39,0xe9,0x4,0x5c,0x17,0x3,0x88,0xba,0x42,0x19,0x4,0x13,0x62,0x9c,0x3e,
  0x8b,0x41,0x4,0x2e,0x7b,0x36,0x9d,0x12,0x76,0x35,0x53,0x99,0xda,0x4a,0x6e,0x3,
  0x6d,0x6c,0x40,0x3b,0x18,0x17,0x30,0xe0,0xe0,0x2e,0xe4,0xe0,0x10,0xb,0x7d,0xe,
  0x33,0x2f,0x87,0x41,0x16,0x7,0xb9,0xd8,0xc7,0xc6,0x18,0x52,0x9f,0x80,0x2c,0x3c,
  0xe0,0x74,0x77,0x87,0x6e,0x18,0x27,0x30,0x3a,0x48,0xc0,0xb8,0xf5,0xae,0xe0,0x1a,
  0x6,0x1f,0xe9,0xb5,0x38,0x3b,0xbb,0x83,0xcb,0x24,0x43,0x5,0x4c,0x93,0x54,0x75,
  0x38,0xa1,0xd7,0x91,0xc,0xc8,0x13,0xbe,0x24,0x54,0x78,0xb8,0x52,0xd9,0x8b,0x76,
  0x0,0xe6,0x7e,0xff,0x47,0xee,0x10,0x2c,0xfd,0x19,0x30,0xde,0x3d,0x9c,0x61,0x30,
  0x70,0xc1,0xcd,0xdb,0x29,0x6f,0xc8,0xcf,0xa1,0x36,0x7f,0x49,0x91,0xf7,0x97,0xf9,
  0x65,0x44,0x85,0xa5,0xde,0x5f,0xec,0x71,0x3c,0x37,0xa1,0xc1,0x18,0x5c,0x5f,0xa1,
  0x7,0x5c,0xd8,0xf6,0x2f,0xb4,0xe0,0xf2,0x1c,0x44,0x23,0x70,0xeb,0x95,0xac,0xff,
  0x78,0x5c,0x34,0x9c,0x43,0xb3,0x44,0x2,0xa6,0xe7,0xcc,0xfd,0x72,0xec,0xf,0x2d,
  0x52,0x75,0x85,0x68,0x9c,0xf8,0xbd,0x68,0xf,0xc4,0x2e,0x7,0xf5,0x6b,0x4e,0xba,
  0xef,0xb0,0xe8,0xe4,0x67,0x32,0xe0,0x18,0xe5,0xdf,0x69,0xb1,0xb,0xb2,0x78,0x60,
  0xac,0x48,0x5,0x6f,0x70,0x12,0xab,0xe3,0x9b,0x2,0x4f,0x62,0xdd,0x38,0xef,0xd,
  0x36,0xd6,0x60,0x3f,0xe7,0xaf,0x6c,0xb1,0x1b,0xac,0xdb,0x2b,0x7a,0x62,0xf4,0x7f,
  0xf5,0xd8,0x4d,0x45,0x28,0x14,0x65,0xd2,0x91,0x65,0xc4,0x67,0x12,0x28,0x51,0x4b,
  0xca,0xa6,0xc,0x72,0xb0,0x25,0x9a,0xf,0x38,0x1d,0x8f,0x7b,0x8,0x4b,0xe8,0x7e,
  0xd8,0x4f,0x2f,0xc6,0xfd,0x67,0xad,0xfb,0xfe,0xef,0x8,0xf8,0xf1,0xa8,0xeb,0xd,
  0x8e,0xda,0xe1,0x3e,0xa9,0x48,0x5b,0xa2,0xea,0x57,0x43,0x33,0x49,0x11,0xec,0xa3,
  0x81,0x42,0xae,0xa4,0x4d,0x2d,0x58,0xa9,0x9f,0xd4,0xa,0xca,0xd5,0x68,0x37,0xc1,
  0xda,0x6a,0xf6,0x36,0xbb,0xb7,0x4a,0xbe,0x5b,0x81,0x69,0x5e,0xab,0x85,0x57,0x9f,
  0x8e,0x34,0x7,0x28,0x87,0x2c,0xd4,0xc2,0x23,0x67,0x2a,0x93,0xf,0x8f,0x37,0x92,
  0x11,0x65,0xd0,0xe0,0xc,0x2a,0x48,0x28,0x88,0x53,0xb9,0x48,0x5b,0x41,0x6f,0x67,
  0x2a,0xdc,0x2e,0x6e,0x9d,0x69,0x10,0x9f,0xaf,0x50,0x8b,0x34,0xc7,0x35,0x6b,0x78,
  0x86,0xeb,0x58,0xaf,0xe9,0x94,0x62,0x95,0xaf,0xc9,0xaf,0x93,0xcd,0x62,0xa,0x1,
  0x83,0x43,0x33,0x75,0xc0,0xbd,0x96,0xb5,0x8d,0xac,0x29,0x2a,0xd2,0x47,0x54,0x34,
  0xf8,0x62,0x83,0xe8,0x1a,0xe7,0x1f,0xa0,0x29,0x3e,0xca,0x12,0x2a,0x8b,0x5d,0xb4,
  0x31,0x79,0xb4,0x99,0x3a,0x14,0x75,0x6,0xd,0x56,0x30,0x91,0xd6,0x58,0xc8,0xb,
  0x3f,0xe0,0xeb,0x62,0x91,0xa4,0x5a,0xf3,0x5,0x8a,0xda,0x2e,0xe0,0x44,0xfe,0xe7,
  0x76,0x95,0x6c,0x45,0x95,0x8c,0xff,0xdf,0x84,0x8d,0x7e,0xb1,0x58,0x75,0x3b,0xbd,
  0x5c,0xea,0x67,0xa7,0xa7,0xfd,0x5a,0x1f,0xcb,0xf7,0x43,0xa8,0x1c,0xd7,0x82,0x50,
  0x35,0x30,0x3,0xbc,0xd9,0xc9,0x67,0xf,0x6f,0xbe,0x98,0x8e,0xe1,0xe9,0x63,0x6d,
  0x6a,0xe1,0x71,0xb9,0x8f,0xda,0x90,0x96,0x11,0x86,0x9b,0x2a,0x47,0x2,0xc8,0x55,
  0xff,0xdb,0x7d,0xf4,0xda,0x7f,0xef,0x73,0xc4,0xf6,0x8,0xaf,0xa4,0x75,0xb6,0x9c,
  0x79,0x34,0x9c,0xac,0xde,0xc4,0xea,0x7c,0xe5,0xc3,0xcd,0x16,0x8b,0xbf,0x63,0xd5,
  0x15,0xc1,0x9e,0xc4,0xd,0x49,0x8f,0xfe,0x0,0xd7,0xf8,0x46,0xff,
  
};

static const unsigned char qt_resource_name[] = {
  // forms
  0x0,0x5,
  0x0,0x6d,0x69,0x43,
  0x0,0x66,
  0x0,0x6f,0x0,0x72,0x0,0x6d,0x0,0x73,
    // form.ui
  0x0,0x7,
  0xd,0x69,0x5,0x79,
  0x0,0x66,
  0x0,0x6f,0x0,0x72,0x0,0x6d,0x0,0x2e,0x0,0x75,0x0,0x69,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/forms
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/forms/form.ui
  0x0,0x0,0x0,0x10,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x9a,0xa1,0x2d,0x18,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_worldtimeclockbuilder)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_worldtimeclockbuilder)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_worldtimeclockbuilder)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_worldtimeclockbuilder)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_worldtimeclockbuilder)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_worldtimeclockbuilder)(); }
   } dummy;
}
